==> apache-druid-0.20.2-src.tar.gz: apache-druid-0.20.2-src/web-console/src/dialogs/snitch-dialog/snitch-dialog.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { render } from '@testing-library/react';
import React from 'react';

import { SnitchDialog } from './snitch-dialog';

describe('snitch dialog', () => {
  it('matches snapshot', () => {
    const snitchDialog = <SnitchDialog title="Be snitchin" onSave={() => {}} onClose={() => {}} />;
    render(snitchDialog);
    expect(document.body.lastChild).toMatchSnapshot();
  });

  it('matches snapshot with history', () => {
    const snitchDialog = (
      <SnitchDialog
        title="Be snitchin"
        onSave={() => {}}
        onClose={() => {}}
        historyRecords={[
          { auditTime: 'test', auditInfo: 'test', payload: JSON.stringify({ name: 'test' }) },
          { auditTime: 'test', auditInfo: 'test', payload: JSON.stringify({ name: 'test' }) },
        ]}
      />
    );
    render(snitchDialog);
    expect(document.body.lastChild).toMatchSnapshot();
  });
});

==> apache-druid-0.22.0-src.tar.gz: apache-druid-0.22.0-src/web-console/src/dialogs/snitch-dialog/snitch-dialog.spec.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { render } from '@testing-library/react';
import * as JSONBig from 'json-bigint-native';
import React from 'react';

import { SnitchDialog } from './snitch-dialog';

describe('snitch dialog', () => {
  it('matches snapshot', () => {
    const snitchDialog = <SnitchDialog title="Be snitchin" onSave={() => {}} onClose={() => {}} />;
    render(snitchDialog);
    expect(document.body.lastChild).toMatchSnapshot();
  });

  it('matches snapshot with history', () => {
    const snitchDialog = (
      <SnitchDialog
        title="Be snitchin"
        onSave={() => {}}
        onClose={() => {}}
        historyRecords={[
          { auditTime: 'test', auditInfo: 'test', payload: JSONBig.stringify({ name: 'test' }) },
          { auditTime: 'test', auditInfo: 'test', payload: JSONBig.stringify({ name: 'test' }) },
        ]}
      />
    );
    render(snitchDialog);
    expect(document.body.lastChild).toMatchSnapshot();
  });
});
